/*******************************************************************
 *
 *	File:		Dialogs.cpp
 *
 *	Author:		Peter van Sebille (peter@yipton.net)
 *
 *	(c) Copyright 2003, Peter van Sebille
 *	All Rights Reserved
 *
 *******************************************************************/

#include "Dialogs.h"
#include <f32file.h>
#include <QikSelectMediaFileDlg.h>
#include <eikchlst.h>
#include <eikchkbx.h>
#include <qiknumbereditor.h>
#include <eikedwin.h>
#include "scap.hrh"
#include <scap.rsg>



/*********************************************
 *
 * CGeneralOptionsDialog
 *
 *********************************************/

enum
{
	EAudioOptionNone = 0,
	EAudioOptionDefault,
	EAudioOptionUser,
	EAudioOptionSelect
};



CGeneralOptionsDialog::CGeneralOptionsDialog(TSCapOptions& aSCapOptions)
	: iSCapOptions(aSCapOptions)
{
}
	

TBool CGeneralOptionsDialog::OkToExitL(TInt /*aButtonId*/)
{
	iSCapOptions.iKey = STATIC_CAST(TSCapKey, iHotkeyChoiceList->CurrentItem());
	iSCapOptions.iManual = (iStopCaptureChoiceList->CurrentItem() == 1) ? ETrue : EFalse;

	iSCapOptions.iSCapAudioOption = STATIC_CAST(TSCapAudioOption, iAudibleFeedbackChoiceList->CurrentItem());
	iSCapOptions.iNoVisual = (iVisualFeedbackCheckBox->State() == CEikButtonBase::EClear) ? ETrue : EFalse;

	return ETrue;
}


void CGeneralOptionsDialog::PreLayoutDynInitL()
{
	iHotkeyChoiceList	= STATIC_CAST(CEikChoiceList*, Control(EIdHotkeyControl));
	iHotkeyChoiceList->SetArrayL(R_HOTKEY_ARRAY);
	iHotkeyChoiceList->SetCurrentItem((TInt)iSCapOptions.iKey);

	iStopCaptureChoiceList	= STATIC_CAST(CEikChoiceList*, Control(EIdStopCaptureControl));
	iStopCaptureChoiceList->SetArrayL(R_STOPCAPTURE_ARRAY);
	iStopCaptureChoiceList->SetCurrentItem(iSCapOptions.iManual ? 1 : 0);

	iVisualFeedbackCheckBox	= STATIC_CAST(CEikCheckBox*, Control(EIdVisualFeedbackControl));
	iVisualFeedbackCheckBox->SetState(iSCapOptions.iNoVisual ? CEikButtonBase::EClear : CEikButtonBase::ESet);

	iAudibleFeedbackChoiceList	= STATIC_CAST(CEikChoiceList*, Control(EIdAudibleFeedbackControl));
	iAudibleFeedbackChoiceList->SetArrayL(R_AUDIBLE_FEEDBACK_ARRAY);
	iAudibleFeedbackChoiceList->SetCurrentItem((TInt)iSCapOptions.iSCapAudioOption);
	if (iSCapOptions.iAudioClip.Length() > 0)
		SetUserDefinedL();
}


void CGeneralOptionsDialog::SetUserDefinedL()
{
	TParsePtr		parse(iSCapOptions.iAudioClip);
	
	iAudibleFeedbackChoiceList->DesCArray()->Delete(2);
	iAudibleFeedbackChoiceList->DesCArray()->InsertL(2, parse.NameAndExt());
}


void CGeneralOptionsDialog::PostLayoutDynInitL()
{
}


void CGeneralOptionsDialog::SelectAudioFileL()
{
	_LIT(KMimeAudio, "audio/*");
	CDesCArray* mimeArray=new( ELeave ) CDesCArrayFlat( 2 );
	CleanupStack::PushL(mimeArray);
	mimeArray->AppendL(KMimeAudio);

	TFileName	fileName;
	if (CQikSelectMediaFileDlg::RunDlgLD(*mimeArray, fileName))
	{
		iSCapOptions.iAudioClip = fileName;
		SetUserDefinedL();
		iAudibleFeedbackChoiceList->SetCurrentItem(EAudioOptionUser);
	}
	else
	{
		iAudibleFeedbackChoiceList->SetCurrentItem(EAudioOptionDefault);
	}

	CleanupStack::PopAndDestroy();		// mimeArray

}


void CGeneralOptionsDialog::HandleControlStateChangeL(TInt aControlId)
{
	if (aControlId == EIdAudibleFeedbackControl)
	{
		TInt option = STATIC_CAST(TSCapKey, iAudibleFeedbackChoiceList->CurrentItem());
			if ((option == EAudioOptionSelect)  || ((option == EAudioOptionUser) && (iSCapOptions.iAudioClip.Length() == 0)))
			SelectAudioFileL();
	}
}


/*********************************************
 *
 * CImageOptionsDialog
 *
 *********************************************/


CImageOptionsDialog::CImageOptionsDialog(TSCapOptions& aSCapOptions)
	: iSCapOptions(aSCapOptions)
{
}
	

TBool CImageOptionsDialog::OkToExitL(TInt /*aButtonId*/)
{
	iSCapOptions.iSCapImageOptions.iImageFormat = (TImageFormat) iImageChoiceList->CurrentItem();
	iSCapOptions.iSCapImageOptions.iQualityFactor = iImageQualityEditor->Value();
	iSCapOptions.iSCapImageOptions.iStorageInternal = (iStorageLocationChoiceList->CurrentItem() == 0 )? ETrue : EFalse;
	iBaseFileNameEdwin->GetText(iSCapOptions.iSCapImageOptions.iBaseFileName);

	return ETrue;
}


void CImageOptionsDialog::PreLayoutDynInitL()
{
	iImageChoiceList = STATIC_CAST(CEikChoiceList*, Control(EIdImageTypeControl));
	iImageChoiceList->SetArrayL(R_IMAGE_TYPE_ARRAY);
	iImageChoiceList->SetCurrentItem((TInt)iSCapOptions.iSCapImageOptions.iImageFormat);

	iImageQualityEditor = STATIC_CAST(CQikNumberEditor*, Control(EIdImageQualityControl));
	iImageQualityEditor->SetValueL(iSCapOptions.iSCapImageOptions.iQualityFactor);

	iStorageLocationChoiceList = STATIC_CAST(CEikChoiceList*, Control(EIdStorageLocationControl));
	iStorageLocationChoiceList->SetArrayL(R_STORAGE_LOCATION_ARRAY);
	iStorageLocationChoiceList->SetCurrentItem(iSCapOptions.iSCapImageOptions.iStorageInternal ? 0 : 1);

	iBaseFileNameEdwin = STATIC_CAST(CEikEdwin*, Control(EIdBaseFilenameControl));
	iBaseFileNameEdwin->SetTextL(&iSCapOptions.iSCapImageOptions.iBaseFileName);

	UpdateImageQualityState();
}


void CImageOptionsDialog::PostLayoutDynInitL()
{
}

void CImageOptionsDialog::UpdateImageQualityState()
{
	TBool	dimImageQuality = (((TImageFormat) iImageChoiceList->CurrentItem()) != EFormatJpg) ? ETrue : EFalse;
	SetLineDimmedNow(EIdImageQualityControl, dimImageQuality);
}

void CImageOptionsDialog::HandleControlStateChangeL(TInt aControlId)
{
	if (aControlId == EIdImageTypeControl)
		UpdateImageQualityState();
}

