/*******************************************************************
 *
 *	File:		SCap.cpp
 *
 *	Author:		Peter van Sebille (peter@yipton.net)
 *
 *	(c) Copyright 2003, Peter van Sebille
 *	All Rights Reserved
 *
 *******************************************************************/


#include "SCap.h"
#include "Dialogs.h"
#include <scap.rsg>
#include <eikenv.h>
#include <eikdialg.h>
#include <eikmenup.h>
#include <eikmsg.h>



class CMyBusyMsgWindow : public CEikMsgWin
{
public:
	static CMyBusyMsgWindow* NewL(RWindowGroup& aWinGroup);
	void DisplayText(const TDesC& aText);
protected:
	CMyBusyMsgWindow(RWindowGroup& aWinGroup);
	void ConstructL();
	RWindowGroup& iWinGroup;
	virtual void DoStartDisplay(const TDesC& aText);
};

CMyBusyMsgWindow* CMyBusyMsgWindow::NewL(RWindowGroup& aWinGroup)
{
	CMyBusyMsgWindow*	self = new(ELeave) CMyBusyMsgWindow(aWinGroup);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);
	return self;
}

CMyBusyMsgWindow::CMyBusyMsgWindow(RWindowGroup& aWinGroup) 
	: CEikMsgWin(*CEikonEnv::Static()), iWinGroup(aWinGroup)
{
}

void CMyBusyMsgWindow::ConstructL()
{
	CEikMsgWin::ConstructL(iWinGroup);
}

void CMyBusyMsgWindow::DisplayText(const TDesC& aText)
{
	CEikMsgWin::StartDisplay(aText, EHRightVTop);
}

void CMyBusyMsgWindow::DoStartDisplay(const TDesC& aText)
{
	iMessageWindow->StartDisplay(ETrue, 0, aText);
}


CApaDocument* CSCapApplication::CreateDocumentL()
{
	CSCapDocument*	doc = new (ELeave) CSCapDocument(*this);

	CleanupStack::PushL(doc);
	doc->ConstructL();
	CleanupStack::Pop();

	return doc;
}



CSCapDocument::CSCapDocument(CEikApplication& aApp)
		: CEikDocument(aApp)
{
}

CSCapDocument::~CSCapDocument()
{
}

void CSCapDocument::ConstructL()
{
}


CEikAppUi* CSCapDocument::CreateAppUiL()
{
	return new(ELeave) CSCapAppUi;
}


CSCapAppUi::~CSCapAppUi()
{
	delete iAppView;
}


void CSCapAppUi::ConstructL()
{
	BaseConstructL();
	
	iSCapEngine = CSCapEngine::NewL();
	iSCapEngine->SetSaveImageObserver(this);

	iAppView=new(ELeave) CSCapAppView;
	iAppView->ConstructL(ClientRect());
	
	iWinGroup=RWindowGroup(CEikonEnv::Static()->WsSession());
	User::LeaveIfError(iWinGroup.Construct((TUint32)&iWinGroup));
	iWinGroup.EnableReceiptOfFocus(EFalse);
	iWinGroup.SetOrdinalPosition(0, 1000);
}


void CSCapAppUi::HandleCommandL(TInt aCommand)
{
	switch (aCommand)
	{
		case EEikCmdExit: 
			Exit();
			break;

		case EEikCmdAbout:
			DisplayAboutDialogL();
			break;

		case EEikCmdGeneralOptions:
			DisplayGeneralOptionsDialogL();
			break;

		case EEikCmdCaptureStartStop:
			iSCapEngine->StartStopCapture();
			break;

		case EEikCmdImageOptions:
			DisplayImageOptionsDialogL();
			break;

		default:
			break;
	}
}

void CSCapAppUi::DisplayGeneralOptionsDialogL()
{
	TSCapOptions	sCapOptions = iSCapEngine->Options();
	CEikDialog*	dialog = new(ELeave) CGeneralOptionsDialog(sCapOptions);
	if (dialog->ExecuteLD(R_DIALOG_GENERAL_OPTIONS) == EEikBidOk)
	{
		iSCapEngine->StartStopCapture();
		iSCapEngine->SaveOptions(sCapOptions);
		iSCapEngine->StartStopCapture();
	}
}


void CSCapAppUi::DisplayImageOptionsDialogL()
{
	TSCapOptions	sCapOptions = iSCapEngine->Options();
	CEikDialog*	dialog = new(ELeave) CImageOptionsDialog(sCapOptions);
	if (dialog->ExecuteLD(R_DIALOG_IMAGE_OPTIONS) == EEikBidOk)
	{
		iSCapEngine->SaveOptions(sCapOptions);
	}
}

void CSCapAppUi::DisplayAboutDialogL()
{
	CEikDialog*	dialog = new(ELeave) CEikDialog;
	dialog->ExecuteLD(R_DIALOG_ABOUT);
}



void CSCapAppUi::DynInitMenuPaneL(TInt aMenuId, CEikMenuPane* aMenuPane)
{
	switch (aMenuId)
	{
		case R_MAME_SCAP_MENU:
			DynInitSCapMenuPaneL(aMenuPane);
			break;
		default:
			break;
	}
}


void CSCapAppUi::DynInitSCapMenuPaneL(CEikMenuPane* aMenuPane)
{
	_LIT(KMenuItemStart, "Start capture");
	_LIT(KMenuItemStop, "Stop capture");
	if (iSCapEngine->IsCapturing())
		aMenuPane->SetItemTextL(EEikCmdCaptureStartStop, KMenuItemStop);
	else
		aMenuPane->SetItemTextL(EEikCmdCaptureStartStop, KMenuItemStart);
}

void CSCapAppUi::HandleWsEventL(const TWsEvent& aEvent, CCoeControl* aDestination)
{
	if (aEvent.Type() == EEventKey)
		iSCapEngine->CaptureScreenIfCaptureKey(aEvent.Key()->iCode);
	CEikAppUi::HandleWsEventL(aEvent, aDestination);
}



void  CSCapAppUi::StartedSavingImage()
{
	FinishedSavingImage();
	if (!iSCapEngine->Options().iNoVisual)
	{
		TRAPD(err, iMyBusyMsgWindow = CMyBusyMsgWindow::NewL(iWinGroup));
		if (iMyBusyMsgWindow)
			iMyBusyMsgWindow->DisplayText(_L("Saving image..."));
	}
}


void  CSCapAppUi::FinishedSavingImage()
{
	delete iMyBusyMsgWindow;
	iMyBusyMsgWindow = NULL;
}


void CSCapAppView::ConstructL(const TRect& aRect)
{
	CreateWindowL();
	SetRect(aRect);
	ActivateL();
}


CSCapAppView::~CSCapAppView()
{
}


void CSCapAppView::Draw(const TRect& aRect) const
{
	CWindowGc& gc = SystemGc();
	gc.Clear(aRect);
}


GLDEF_C TInt E32Dll(TDllReason)
{
	return KErrNone;
}

EXPORT_C CApaApplication* NewApplication()
{
	return new CSCapApplication;
}



TUid CSCapApplication::AppDllUid() const
{
	return KUidSCapApp;
}



