/*******************************************************************
 *
 *	File:		SCapEng.h
 *
 *	Author:		Peter van Sebille (peter@yipton.net)
 *
 *	(c) Copyright 2003, Peter van Sebille
 *	All Rights Reserved
 *
 *******************************************************************/

#ifndef __SCAP_ENG_H
#define __SCAP_ENG_H

#include <e32def.h>
#include <e32base.h>
#include <w32std.h>
#include <MdaImageConverter.h>
#include <MdaAudioSamplePlayer.h>


class MSaveImageObserver
{
public:
	virtual void StartedSavingImage() = 0;
	virtual	void FinishedSavingImage() = 0;
};


class CFbsBitmap;

enum TSCapAudioOption
{
	EAudioSilent,
	EAudioDefault,
	EAudioUserDefined
};

enum TImageFormat
{
	EFormatBmp24,
	EFormatBmp8,
	EFormatGif,
	EFormatJpg
};


enum TSCapKey
{
	ECaptureCamera,
	ECaptureBrowser,
	ECapturePower,
	ECaptureJogdialSelect
};

class TSCapImageOptions
{
public:
	TImageFormat	iImageFormat;
	TInt			iQualityFactor;	// jpg
	TBool			iStorageInternal;
	TFileName		iBaseFileName;
};

class TSCapOptions
{
public:
	TSCapAudioOption	iSCapAudioOption;
	TFileName			iAudioClip;
	TBool				iManual;
	TBool				iNoVisual;
	TSCapKey			iKey;
	TSCapImageOptions	iSCapImageOptions;
};


class CSCapEngine : public CBase, public MMdaImageUtilObserver, public MMdaAudioPlayerCallback
{
public:
	~CSCapEngine();
	static CSCapEngine*		NewL();

	void SetSaveImageObserver(MSaveImageObserver* aSaveImageObserver){iSaveImageObserver = aSaveImageObserver;}

	const TSCapOptions&	Options() const {return iSCapOptions;}
	void SetOptions(const TSCapOptions& aOptions);

	void StartStopCapture();

	TBool IsCapturing() {return iIsCapturing;}

	void CaptureScreenIfCaptureKey(TInt aKeyCode);

	void SaveOptions(const TSCapOptions& aSCapOptions);
protected:
	TBool	IsBusy();

	void ConstructL();
	void LoadOptions();
	void DefaultOptions();

	void StartCaptureL();
	void StartCapture();
	void StopCapture();
	void CaptureScreen();
	void SavingImageComplete(TInt aErr);

	void CaptureKey();
	void CancelCaptureKey();

	void CreateBitmapL();
	void DestroyBitmap();

	void SaveImage();
	void SaveImageL();

	void MkFileNameL(TFileName& aFileName, const TDesC& aExt);
	TBool MkFileName(TFileName& aFileName, const TDesC& aExt, TBool aInternal);

	TBool			iIsSavingImage;
	TSCapOptions	iSCapOptions;
	TBool			iIsCapturing;
	TInt32			iCaptureKey;
	CFbsBitmap*		iBitmap;

	TInt Save(const CFbsBitmap& aBitmap, const TSCapImageOptions& aSCapImageOptions);
	TMdaBmpClipFormat		iBmpFormat;
	TMda8BppBmpCodec		iBmp8BppCodec;
	TMda24BppBmpCodec		iBmp24BppCodec;

	TMdaGif87aClipFormat	iGifFormat;
	TMdaGifCodec			iGifCodec;

	TMdaJfifClipFormat		iJfifFormat;

	CMdaImageBitmapToFileUtility*	iMdaUtil;
	
	MSaveImageObserver* 	iSaveImageObserver;

public:			// implements MMdaImageUtilObserver
	virtual void MiuoOpenComplete(TInt aError);
	virtual void MiuoCreateComplete(TInt aError);
	virtual void MiuoConvertComplete(TInt aError);

public:			// implements MMdaAudioPlayerCallback
	virtual void MapcInitComplete(TInt aError, const TTimeIntervalMicroSeconds& aDuration);
	virtual void MapcPlayComplete(TInt aError);

protected:
	TBool	iIsPlaying;
	void PlayOkSound();
	CMdaAudioPlayerUtility*		iUtility;
};

#endif			/* __SCAP_ENG_H */

